@@ -387,8 +387,11 @@ void Bayonne::compileDir(const char *prefix, ScriptCompiler *img)
 	while(NULL != (file = dir.getName()))
 	{
 		ext = strrchr(file, '.');
+		if(ext && strstr(Script::exec_extensions, ext))
+			goto compile;
 		if(!ext || stricmp(ext, ".scr"))
 			continue;
+compile:
 		setString(pp, len, file);
 		img->compile(path);
 	}
@@ -478,8 +481,12 @@ ScriptCompiler *Bayonne::reload(void)
 			break;
 
 		ext = strrchr(prefix, '.');
+		if(ext && strstr(Script::exec_extensions, ext))
+			goto compile;
+
 		if(!ext || stricmp(ext, ".scr"))
 			continue;
+compile:
 		prefix = server->getLast(prefix);
 		img->compile(prefix);
 	}
