@@ -429,6 +429,8 @@ public:
 		RESULT_PENDING,
 		RESULT_COMPLETE,
 		RESULT_FAILED,
+		RESULT_BADPATH = 254,
+		RESULT_OFFLINE = 255
 	}	result_t;
 
 	typedef	struct
