@@ -47,11 +47,14 @@ static bool err = false;
 static int buffers = 1024;
 static socklen_t blen = sizeof(buffers);
 static const char *libpath;
+static const char *syspath;
 static int slots;
 static int iosock;
 static int interval = 5;
 static int server_pid = 0;
 
+static void stop(void);
+
 extern "C" {
 
 RETSIGTYPE timer(int signo)
@@ -62,6 +65,7 @@ RETSIGTYPE timer(int signo)
 			fprintf(stderr, "libexec exiting; server lost\n");
 		else
 			slog.notice("server lost...");
+		stop();
 		::exit(0);
 	}
 	alarm(interval);
@@ -105,6 +109,20 @@ RETSIGTYPE child(int signo)
 
 };
 
+static void stop(void)
+{
+	unsigned count = 0;
+	if(!slot || !slots)
+		return;
+
+	while(count < slots)
+	{
+		if(slot[count].pid)
+			kill(slot[count].pid, SIGTERM);
+		++count;
+	}
+}
+
 BayonneSysexec::BayonneSysexec() :
 Thread(0)
 {
@@ -268,7 +286,10 @@ void BayonneSysexec::execute(unsigned ts, const char *cmd)
 	char *args[2];
 	unsigned count = 3;
 
-	snprintf(path, sizeof(path), "%s/%s", libpath, cmd);
+	if(!strnicmp(cmd, "exec::", 6))
+		snprintf(path, sizeof(path), "%s/%s", syspath, cmd + 6);
+	else
+		snprintf(path, sizeof(path), "%s/%s", libpath, cmd);
 	snprintf(fname, sizeof(fname), "%s/.libexec-%d", path_tmp, ts);
 
 	args[0] = path;
@@ -388,6 +409,12 @@ void BayonneSysexec::allocate(const char *libexec, size_t bs, int pri, const cha
 		return;
 	}
 
+	syspath = Process::getEnv("SERVER_SYSEXEC");
+	if(!syspath)
+		syspath = Process::getEnv("SERVER_SCRIPTS");
+	if(!syspath)
+		syspath = libpath;
+
 	Process::detach();
 	dup2(fd, 2);
 	::close(fd);
@@ -434,6 +461,7 @@ void BayonneSysexec::allocate(const char *libexec, size_t bs, int pri, const cha
 				fprintf(stderr, "libexec exiting; server down\n");
 			else
 				slog.notice("libexec exiting...");
+			stop();
 			::exit(0);
 		}
 
@@ -455,13 +483,21 @@ void BayonneSysexec::allocate(const char *libexec, size_t bs, int pri, const cha
 bool BayonneSysexec::create(BayonneSession *s)
 {
 	char buf[LIBEXEC_BUFFER];
+	const char *lib;
+	Name *scr = s->getName();
+	Line *line = s->getLine();
 
 	if(iopair[1] < 0)
 		return false;
 
+	if(!strnicmp(line->cmd, "exec", 4))
+		lib = scr->name;
+	else
+		lib = s->getValue();
+
 	s->newTid();
 	snprintf(buf, sizeof(buf), "%04d+%08lx %s", 
-		s->getSlot(), s->newTid(), s->getValue());
+		s->getSlot(), s->newTid(), lib);
 	write(iopair[1], buf, sizeof(buf));
 	return true;
 }
