@@ -307,13 +307,15 @@ void BayonneTSession::sysArgs(const char *tsid)
         const char *cp;
 	char *up;
 	unsigned opt = 0;
+	Line *line = getLine();
 
         enter();
         if(isLibexec(tsid))
         {  
 		libWrite("300 ARGUMENTS\n");
 		frame[stack].index = 0;
-		cp = getOption(NULL);
+		if(strnicmp(line->cmd, "exec", 4))
+			cp = getOption(NULL);
 		while(NULL != (cp = getOption(NULL)))
 		{
 			if(*cp == '%' || *cp == '&')
