@@ -122,7 +122,7 @@ sub hangup($) {
 
 # disconnect (server resumes...)
 
-sub resume($$) {
+sub detach($$) {
 	my($self,$code) = @_;
 	my($tsid) = $self->{tsession};
 
@@ -420,7 +420,7 @@ sub size($$$) {
 	
 # build prompt
 
-sub prompt($$) {
+sub speak($$) {
         my($self, $buf) = @_;
 	my($voice) = $self->{voice};
 
