@@ -332,6 +332,9 @@ const char *Checks::chkLibexec(Line *line, ScriptImage *img)
 	if(cp && atoi(++cp) < 1)
 		return "libexec timeout member must be at least one second";
 
+	if(!strnicmp(line->cmd, "exec", 4))
+		goto get;
+
 	cp = getOption(line, &idx);
 	if(!cp)
 		return "libexec requires command argument";
@@ -342,6 +345,7 @@ const char *Checks::chkLibexec(Line *line, ScriptImage *img)
 	if(strchr(cp, '/') || strchr(cp, '\\'))
 		return "libexec command cannot be path";
 
+get:
 	while(NULL != (cp = getOption(line, &idx)))
 	{
 		if(*cp != '%' && *cp != '&' && *cp != '#')
