@@ -326,6 +326,14 @@ static void commonConfig(void)
 		Script::symsize = atoi(cp);	
 
 	Script::fastStart = false;
+
+#ifdef	WIN32
+	Script::exec_extensions = SCRIPT_EXTENSIONS;
+#else
+	Script::exec_extensions = SCRIPT_EXTENSIONS;
+#endif
+	Script::exec_token = "bayonne:";
+	Script::exec_prefix = "exec";
 }
 
 void testConfig(char *argv0)
@@ -756,7 +764,7 @@ skip:
 			else
 				keyoptions.setValue("modules", path);
 		}
-		else if(!stricmp(ext, ".scr"))
+		else if(!stricmp(ext, ".scr") || strstr(Script::exec_extensions, ext))
 		{
 			prefix = strrchr(*argv, '/');
 			if(!prefix)
@@ -796,7 +804,16 @@ skip:
 		runtime.setValue("scripts", keypaths.getLast("scripts"));
 		return;
 	}
-	
+
+	snprintf(path, sizeof(path), "%s", script);
+	ext = strrchr(path, '/');
+	if(!ext)
+		ext = strrchr(path, '\\');
+	if(ext)
+		*ext = 0;
+	else
+		getcwd(path, sizeof(path));
+	Process::setEnv("SERVER_SYSEXEC", path, true);
 	option = strrchr(script, '/');
 	if(!option)
 		option = strrchr(script, '\\');
@@ -804,13 +821,18 @@ skip:
 		option = strrchr(script, ':');
 	if(option)
 		script = ++option;
-	setString(buffer, sizeof(buffer), script);
+	ext = strrchr(script, '.');
+	if(ext && strstr(Script::exec_extensions, ext))
+		snprintf(buffer, sizeof(buffer), "exec::%s", script);
+	else
+		setString(buffer, sizeof(buffer), script);
 	script = buffer;
 	ext = strrchr(script, '.');
-	if(ext)
+	if(ext && !strstr(Script::exec_extensions, ext))
 		*ext = 0;
 
 	runtime.setValue("startup", script);
+	printf("STARTUP %s\n", script);
 }		
 
 void dumpConfig(Keydata &keydef)
